@@ -24,6 +24,7 @@ extern int yyparse(); /* call bison parser */
 extern int switch_nesting;
 
 /* ------------- local functions ---------------- */
+static void load_pop_multi(struct command *, int); /* put correct value into preceding pop_multi-statement */
 
 /* ------------- global variables ---------------- */
 static struct command *labelroot = NULL; /* first label among commands */
@@ -87,9 +88,9 @@ void reorder_stack_after_call(
                          and remove switch value (if any) */
 {
   struct stackentry *keep, *kept;
-  char *kept_string;
-  double kept_value;
-  int kept_type;
+  char *kept_string = NULL;
+  double kept_value = 0;
+  int kept_type = 0;
 
   if (keep_topmost) {
     keep = pop(stANY);
@@ -283,12 +284,10 @@ void makelocal(struct command *cmd) /* makes symbol local */
 
 void create_count_params(void) /* create command 'cCOUNT_PARAMS' */
 {
-  struct command *cmd;
-
   /* dotifying numparams at compiletime (as opposed to runtime) is essential,
      because the function name is not known at runtime */
-  cmd = add_command_with_sym_and_diag(cCOUNT_PARAMS, dotify("numparams", FALSE),
-                                      NULL);
+  add_command_with_sym_and_diag(cCOUNT_PARAMS, dotify("numparams", FALSE),
+                                NULL);
 }
 
 void count_params(struct command *cmd) /* count number of function parameters */
@@ -669,15 +668,14 @@ void pop_multi(
     struct command *cmd) /* pop and discard multiple values from stack */
 {
   int to_pop = cmd->tag;
-  struct stackentry *popped;
 
   while (to_pop > 0) {
-    popped = pop(stSTRING_OR_NUMBER);
+    pop(stSTRING_OR_NUMBER);
     to_pop--;
   }
 }
 
-void load_pop_multi(
+static void load_pop_multi(
     struct command *cmd,
     int to_pop) /* put correct value into preceding pop_multi-statement */
 {
@@ -835,7 +833,7 @@ void next_case(struct command *cmd) /* find next_case_here statement */
   cmd->jump = currcmd = curr;
 }
 
-void findnop()
+void findnop(void)
 /* used for on_gosub, find trailing nop command */
 {
   while (currcmd->type != cNOP) {
