@@ -41,7 +41,8 @@ static int do_system(
     char *); /* hand over execution of command to system, return exit code */
 static char *do_system2(char *); /* hand over execution of command to system,
                                     return output as string */
-static double myrand();          /* generate random number in given range */
+static double myrand(void);          /* generate random number in given range */
+static char *recall_buff(void);      /* recall store buffer */
 
 /* ------------- global variables ---------------- */
 
@@ -370,14 +371,13 @@ void create_function(int type) /* create command 'function' */
 
 void function(struct command *cmd) /* performs a function */
 {
-  struct stackentry *stack, *a1, *a2, *a3, *a4;
+  struct stackentry *stack, *a1 = NULL, *a2 = NULL, *a3 = NULL, *a4 = NULL;
   char *pointer;
   double value;
   time_t datetime;
-  int type, result, len, start, i, j, k, max, cnt, sz;
+  int type, result, len, start, i, j, k, max, cnt;
   char *str, *str2;
 
-  a3 = NULL;
   type = cmd->args;
   if (type > fTHREEARGS) {
     a4 = pop(stSTRING_OR_NUMBER);
@@ -712,7 +712,9 @@ void function(struct command *cmd) /* performs a function */
   case fSTRING:
     cnt = (int)a1->value;
     if (cnt < 0) {
-      sprintf(estring, "first argument to function 'string$' must be > 0, but found %d", cnt);
+      sprintf(estring,
+              "first argument to function 'string$' must be > 0, but found %d",
+              cnt);
       error(sERROR, estring);
       return;
     }
@@ -722,7 +724,7 @@ void function(struct command *cmd) /* performs a function */
     k = 0;
     for (i = 0; i < cnt; i++) {
       for (j = 0; j < len; j++) {
-	pointer[k++] = str[j];
+        pointer[k++] = str[j];
       }
     }
     pointer[k] = '\0';
@@ -975,7 +977,7 @@ static int do_system(
 #endif
 }
 
-static double myrand() {
+static double myrand(void) {
   long ran;
 
   ran = (((long)rand()) & 0x7fffL) << 15 | ((long)rand() & 0x7fffL);
@@ -999,7 +1001,7 @@ static void store_buff(char *buff, int len) /* store system-input buffer */
   buffcount++;
 }
 
-char *recall_buff() /* recall store buffer */
+static char *recall_buff(void) /* recall store buffer */
 {
   struct buff_chain *curr, *old;
   char *result;
@@ -1435,7 +1437,7 @@ static char *fromto(char *str, int from,
   return part;
 }
 
-void mywait() /* wait given number of seconds */
+void mywait(void) /* wait given number of seconds */
 {
   double delay;
 
@@ -1461,7 +1463,7 @@ void mywait() /* wait given number of seconds */
 #endif
 }
 
-void mybell() /* ring ascii bell */
+void mybell(void) /* ring ascii bell */
 {
 #ifdef UNIX
   printf("\007");
@@ -1487,7 +1489,7 @@ void poke(struct command *cmd) /* poke into internals */
 {
   char *dest, *s, c;
   char *string_arg = NULL;
-  double double_arg;
+  double double_arg = 0;
   struct stackentry *stack;
   int count;
 
@@ -1524,35 +1526,48 @@ void poke(struct command *cmd) /* poke into internals */
     } else if (!strcmp(string_arg, "x11_note_on_receive_expose")) {
       x11_note_on_receive_expose = TRUE;
     } else {
-      sprintf(estring, "invalid argument for poke 'debug_internal': '%s' ; allowed values are:\n"
-	      "     x11_send_expose             :   send an artifical expose event to the open graphic window\n"
-	      "     x11_note_on_receive_expose  :   make the redraw-coprocess output a note on\n"
-	      "       receiving an x11 expose; infolevel must be set to 'note' at minimum;\n"
-	      "       this needs to be issued before opening a window", string_arg);
+      sprintf(estring,
+              "invalid argument for poke 'debug_internal': '%s' ; allowed "
+              "values are:\n"
+              "     x11_send_expose             :   send an artificial expose "
+              "event to the open graphic window\n"
+              "     x11_note_on_receive_expose  :   make the redraw-coprocess "
+              "output a note on\n"
+              "       receiving an x11 expose; infolevel must be set to 'note' "
+              "at minimum;\n"
+              "       this needs to be issued before opening a window",
+              string_arg);
       error(sERROR, estring);
     }
 
-  } else if (!strcmp(dest, "console_foreground_intensity") || !strcmp(dest, "screen_foreground_intensity") || !strcmp(dest, "terminal_foreground_intensity")) {
+  } else if (!strcmp(dest, "console_foreground_intensity") ||
+             !strcmp(dest, "screen_foreground_intensity") ||
+             !strcmp(dest, "terminal_foreground_intensity")) {
     if (con_xcap_inized) {
-      /* Remark: it is tempting to loosen the below restriction. However, doing this would
-	 open a can of bugs and missing implementation-details. E.g. currently we have no
-	 intensity in the result of getscreen$(), but we would need this, if intensity could
-	 be changed multiple times during program run. */
-      sprintf(estring, "console_foreground_intensity cannot be changed after 'clear screen' has been called");
+      /* Remark: it is tempting to loosen the below restriction. However, doing
+         this would open a can of bugs and missing implementation-details. E.g.
+         currently we have no intensity in the result of getscreen$(), but we
+         would need this, if intensity could be changed multiple times during
+         program run. */
+      sprintf(estring, "console_foreground_intensity cannot be changed after "
+                       "'clear screen' has been called");
       error(sERROR, estring);
     } else {
       if (!strcmp(string_arg, "legacy")) {
-	con_fore_inten = cciLEGACY;
+        con_fore_inten = cciLEGACY;
       } else if (!strcmp(string_arg, "bright")) {
-	con_fore_inten = cciBRIGHT;
+        con_fore_inten = cciBRIGHT;
       } else if (!strcmp(string_arg, "normal")) {
-	con_fore_inten = cciNORMAL;
+        con_fore_inten = cciNORMAL;
       }
     }
-  } else if (!strcmp(dest, "console_foreground_color") || !strcmp(dest, "screen_foreground_color") || !strcmp(dest, "terminal_foreground_color")) {
+  } else if (!strcmp(dest, "console_foreground_color") ||
+             !strcmp(dest, "screen_foreground_color") ||
+             !strcmp(dest, "terminal_foreground_color")) {
     if (con_xcap_inized) {
       /* Maybe see remark above for console_foreground_intensity */
-      sprintf(estring, "console_foreground_color cannot be changed after 'clear screen' has been called");
+      sprintf(estring, "console_foreground_color cannot be changed after "
+                       "'clear screen' has been called");
       error(sERROR, estring);
     }
     con_fore_col = name2yc(string_arg);
@@ -1560,10 +1575,13 @@ void poke(struct command *cmd) /* poke into internals */
       sprintf(estring, "unknown foreground colour: '%s'", string_arg);
       error(sERROR, estring);
     }
-  } else if (!strcmp(dest, "console_background_color") || !strcmp(dest, "screen_background_color") || !strcmp(dest, "terminal_background_color")) {
+  } else if (!strcmp(dest, "console_background_color") ||
+             !strcmp(dest, "screen_background_color") ||
+             !strcmp(dest, "terminal_background_color")) {
     if (con_xcap_inized) {
       /* Maybe see remark above for console_foreground_intensity */
-      sprintf(estring, "console_background_color cannot be changed after 'clear screen' has been called");
+      sprintf(estring, "console_background_color cannot be changed after "
+                       "'clear screen' has been called");
       error(sERROR, estring);
     }
     con_back_col = name2yc(string_arg);
@@ -1631,7 +1649,11 @@ void poke(struct command *cmd) /* poke into internals */
     } else {
       sprintf(string, "invalid poke: '%s', %g", dest, double_arg);
     }
-    strncat(string, "; either the first argument is totally unknown (see the documentation of 'poke') or it expects a different type of second argument (string/number) than given", INBUFFLEN - 1 - strlen(string));
+    strncat(string,
+            "; either the first argument is totally unknown (see the "
+            "documentation of 'poke') or it expects a different type of second "
+            "argument (string/number) than given",
+            INBUFFLEN - 1 - strlen(string));
     error(sERROR, string);
   }
   return;
@@ -1639,14 +1661,14 @@ void poke(struct command *cmd) /* poke into internals */
 
 void pokefile(struct command *cmd) /* poke into file */
 {
-  char *sarg = NULL;
-  double darg;
+  char *string_arg = NULL;
+  double double_arg = 0;
   int stream;
 
   if (cmd->tag == 'S') {
-    sarg = pop(stSTRING)->pointer;
+    string_arg = pop(stSTRING)->pointer;
   } else {
-    darg = pop(stNUMBER)->value;
+    double_arg = pop(stNUMBER)->value;
   }
   stream = (int)(pop(stNUMBER)->value);
 
@@ -1659,14 +1681,14 @@ void pokefile(struct command *cmd) /* poke into file */
     error(sERROR, string);
     return;
   }
-  if (sarg) {
-    fputs(sarg, streams[stream]);
+  if (string_arg) {
+    fputs(string_arg, streams[stream]);
   } else {
-    if (darg < 0 || darg > 255) {
+    if (double_arg < 0 || double_arg > 255) {
       error(sERROR, "stream poke out of byte range (0..255)");
       return;
     }
-    fputc((int)darg, streams[stream]);
+    fputc((int)double_arg, streams[stream]);
   }
 }
 
@@ -1688,10 +1710,12 @@ static double peek(char *dest) /* peek into internals */
   } else if (!strcmp(dest, "screenwidth")) {
     return COLS;
   } else if (!strcmp(dest, "displaywidth")) {
-    if (displaywidth == 0) determine_display_size();
+    if (displaywidth == 0)
+      determine_display_size();
     return displaywidth;
   } else if (!strcmp(dest, "displayheight")) {
-    if (displayheight == 0) determine_display_size();
+    if (displayheight == 0)
+      determine_display_size();
     return displayheight;
   } else if (!strcmp(dest, "argument") || !strcmp(dest, "arguments")) {
     return yabargc;
@@ -1709,10 +1733,13 @@ static double peek(char *dest) /* peek into internals */
   } else if (!strcmp(dest, "millisrunning")) {
     return (double)(current_millis() - compilation_start);
   } else if (dest[0] == '#') {
-      error(sERROR, "don't use quotes when peeking into a file");
+    error(sERROR, "don't use quotes when peeking into a file");
     return 0;
   }
-  sprintf(string, "invalid peek: '%s'; see the documentation of 'peek' for accepted values", dest);
+  sprintf(
+      string,
+      "invalid peek: '%s'; see the documentation of 'peek' for accepted values",
+      dest);
   error(sERROR, string);
   return 0;
 }
@@ -1751,7 +1778,9 @@ static char *peek2(char *dest, struct command *curr) /* peek into internals */
     } else {
       return my_strdup("unknown");
     }
-  } else if (!strcmp(dest, "console_foreground_intensity") || !strcmp(dest, "screen_foreground_intensity") || !strcmp(dest, "terminal_foreground_intensity")) {
+  } else if (!strcmp(dest, "console_foreground_intensity") ||
+             !strcmp(dest, "screen_foreground_intensity") ||
+             !strcmp(dest, "terminal_foreground_intensity")) {
     if (con_fore_inten == cciLEGACY) {
       return my_strdup("legacy");
     } else if (con_fore_inten == cciBRIGHT) {
@@ -1762,13 +1791,17 @@ static char *peek2(char *dest, struct command *curr) /* peek into internals */
       /* cannot happen, but anyway */
       return my_strdup("unknown");
     }
-  } else if (!strcmp(dest, "console_foreground_color") || !strcmp(dest, "screen_foreground_color") || !strcmp(dest, "terminal_foreground_color")) {
+  } else if (!strcmp(dest, "console_foreground_color") ||
+             !strcmp(dest, "screen_foreground_color") ||
+             !strcmp(dest, "terminal_foreground_color")) {
     if (con_fore_col == -1) {
       return my_strdup("unset");
     } else {
       return yc2name(con_fore_col);
     }
-  } else if (!strcmp(dest, "console_background_color") || !strcmp(dest, "screen_background_color") || !strcmp(dest, "terminal_background_color")) {
+  } else if (!strcmp(dest, "console_background_color") ||
+             !strcmp(dest, "screen_background_color") ||
+             !strcmp(dest, "terminal_background_color")) {
     if (con_back_col == -1) {
       return my_strdup("unset");
     } else {
@@ -1810,7 +1843,9 @@ static char *peek2(char *dest, struct command *curr) /* peek into internals */
       s = "";
     }
     return my_strdup(s);
-  } else if (!strcmp(dest, "console_color_mode") || !strcmp(dest, "screen_color_mode") || !strcmp(dest, "terminal_color_mode")) {
+  } else if (!strcmp(dest, "console_color_mode") ||
+             !strcmp(dest, "screen_color_mode") ||
+             !strcmp(dest, "terminal_color_mode")) {
     if (con_fore_inten == cciLEGACY) {
       return my_strdup("legacy");
     } else if (con_fore_inten == cciBRIGHT) {
@@ -1818,12 +1853,18 @@ static char *peek2(char *dest, struct command *curr) /* peek into internals */
     } else if (con_fore_inten == cciNORMAL) {
       return my_strdup("standard");
     } else {
-      sprintf(estring, "Internal error: Invalid value for console_foreground_intensity: %d", con_fore_inten);
+      sprintf(
+          estring,
+          "Internal error: Invalid value for console_foreground_intensity: %d",
+          con_fore_inten);
       error(sERROR, estring);
       return my_strdup("");
     }
   } else {
-    sprintf(string, "invalid peek: '%s'; see the documentation of 'peek$' for accepted values", dest);
+    sprintf(string,
+            "invalid peek: '%s'; see the documentation of 'peek$' for accepted "
+            "values",
+            dest);
     error(sERROR, string);
   }
   return my_strdup("");
@@ -2028,6 +2069,10 @@ void create_dblrelop(char c) /* create command dblrelop */
   case '}':
     type = cGE;
     break;
+  default:
+    sprintf(string, "unknown dblrelop char: '%c'", c);
+    error(sERROR, string);
+    type = 0;
   }
   add_command(type);
 }
@@ -2058,6 +2103,10 @@ void dblrelop(struct command *cmd) /* compare topmost double-values */
   case cGT:
     c = (a > b);
     break;
+  default:
+    /* this is an error, but handled already in create_dblrelop; code below only
+     * to silence compiler */
+    c = 0;
   }
   result = push();
   result->value = c;
@@ -2087,6 +2136,10 @@ void create_strrelop(char c) /* create command strrelop */
   case '}':
     type = cSTRGE;
     break;
+  default:
+    sprintf(string, "unknown strrelop char: '%c'", c);
+    error(sERROR, string);
+    type = 0;
   }
   add_command(type);
 }
@@ -2118,6 +2171,10 @@ void strrelop(struct command *cmd) /* compare topmost string-values */
   case cSTRGE:
     c = (strcmp(a, b) >= 0);
     break;
+  default:
+    /* this is an error, but handled already in create_strrelop; code below only
+     * to silence compiler */
+    c = 0;
   }
   result = push();
   result->value = c;
@@ -2197,6 +2254,10 @@ void create_boole(char c) /* create command boole */
   case '!':
     type = cNOT;
     break;
+  default:
+    sprintf(string, "unknown boole char: '%c'", c);
+    error(sERROR, string);
+    type = 0;
   }
   add_command(type);
 }
